@@ -250,10 +250,10 @@ struct multiple_size
     char *min;
     char *max;
 
-    /* if no limit is specified then initialized to -1.
-       if the same size is specified for min and max, it means that a precise
+    /* if no limit is specified then initialized to 0.
+       if the same size is specified for min and max, it means that an exact
        number of occurrences is required*/
-    multiple_size(const char *m = "-1", const char *M = "-1") :
+    multiple_size(const char *m = "0", const char *M = "0") :
         min(strdup(m)), max(strdup(M))
     {}
 };
@@ -2046,12 +2046,12 @@ yyreduce:
 
   case 64:
 #line 549 "parser.yy"
-    { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (4)].str), "-1"); free((yyvsp[(2) - (4)].str)); }
+    { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (4)].str), "0"); free((yyvsp[(2) - (4)].str)); }
     break;
 
   case 65:
 #line 550 "parser.yy"
-    { (yyval.multiple_size) = new multiple_size("-1", (yyvsp[(3) - (4)].str)); free((yyvsp[(3) - (4)].str)); }
+    { (yyval.multiple_size) = new multiple_size("0", (yyvsp[(3) - (4)].str)); free((yyvsp[(3) - (4)].str)); }
     break;
 
   case 66:
