@@ -33,6 +33,9 @@ main (int argc, char **argv)
         printf ("\n");
     }
 
+  if (args_info.hidden_given)
+    printf ("specified --hidden: %d\n", args_info.hidden_arg);
+
   if (args_info.file_save_given && test_all_opts_cmd_parser_file_save (args_info.file_save_arg, &args_info) != EXIT_SUCCESS)
     exit(1) ;
 
